@@ -15,11 +15,15 @@ def schedule(args):
             roles_node[role_name].setValue(subject_id)
         else:
             roles_node[role_name].setValue('?????')
+        roles_node[role_name].removeAllChildren()
     schedule_org = None
     if os.path.isfile('session_schedule.org'):
         schedule_org = SAPOFTO.SAPOFTO('SCHEDULE',filename='session_schedule.org')
+        if not  str(session_archetype) + ' SCHEDULE' in schedule_org.keys():
+            schedule_org.addChild(SAPOFTO.SAPOFTO(str(session_archetype) + ' SCHEDULE'))
     else:
         schedule_org = SAPOFTO.SAPOFTO('SCHEDULE')
+        schedule_org.addChild(SAPOFTO.SAPOFTO(str(session_archetype) + ' SCHEDULE'))        
     session_id = input('Please input the session\'s ID, or press enter to autogenerate a new ID...')
     if session_id == '':
         if os.path.isdir(os.path.join('sessions',session_archetype)):
@@ -46,7 +50,9 @@ def schedule(args):
     session_key = 'TODO ' + session_archetype + str(session_id)
     schedule_org.addChild(SAPOFTO.SAPOFTO(key=session_key))
     schedule_org[session_key].addChild(roles_node)
-    schedule_org.promote(1)
+    with open('session_schedule.org', 'w') as f:
+        f.write(str(schedule_org.castOrgLiteral()))
+
     
 
     
